Index: /drbl-green-benchmark/diskfull-benchmark.sh
===================================================================
--- /drbl-green-benchmark/diskfull-benchmark.sh	(revision 98)
+++ /drbl-green-benchmark/diskfull-benchmark.sh	(revision 99)
@@ -5,11 +5,13 @@
 log_start=$(date +"%y%m%d-%H%M%S_")
 log_file="/var/log/${log_start}diskfull-benchmark.log"
-status_file="/var/log/${log_start}diskfull-benchmark-status.log"
+#status_file="/var/log/${log_start}diskfull-benchmark-status.log"
+status_file="/dev/null"
 local_zip="/var/log/${log_start}diskfull.tar.gz"
 echo "0. Rebooting...." > $log_file
 echo "0. Rebooting...."
-/opt/drbl/sbin/dcs -h "$IP_LIST" local 2>&1 > $status_file
+/opt/drbl/sbin/dcs -h "$IP_LIST" local > $status_file 2>&1
 source /home/jazz/.bash_aliases
 up-host-a > /root/.dsh/machines.list
+rm -f /root/.ssh/known_hosts
 
 function mydsh()
@@ -22,5 +24,6 @@
   echo "[$i] 1. Booting...." >> $log_file
   echo "[$i] 1. Booting...."
-  dsh -a -c "reboot" 2>&1 >> $status_file
+  dsh -a -c "rm -f /var/log/*.time.*" >> $status_file 2>&1
+  dsh -a -c "reboot" >> $status_file 2>&1
   `date >> $log_file`
   sleep 120
@@ -41,6 +44,6 @@
   echo "[$i] 4. Running bonnie++ ...."
   `date >> $log_file`
-  # force to run bonnie++ with 512MB RAM (-r), 1024MB (-s)
-  mydsh "$i" "bonnie++" "bonnie++ -u root -d /root -r 512 -s 1024"
+  # force to run bonnie++ with 128MB RAM (-r), 256MB (-s)
+  mydsh "$i" "bonnie++" "bonnie++ -u root -d /root -r 128 -s 256"
   `date >> $log_file`
   sleep 120
@@ -60,26 +63,20 @@
   mydsh "$i" "make-allnoconf" "make -C /tmp/linux-2.6.30 allnoconfig"
   `date >> $log_file`
-  echo "[$i] 5. Running make -j 1 twice ...." >> $log_file
-  echo "[$i] 5. Running make -j 1 twice ...."
+  echo "[$i] 5. Running make -j 1 once ...." >> $log_file
+  echo "[$i] 5. Running make -j 1 once ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-1" "make-j1" "make -j 1 -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-j1" "make -j 1 -C /tmp/linux-2.6.30"
   `date >> $log_file`
   sleep 120
-  echo "[$i] 6. Running make -j 2 triple ...." >> $log_file
-  echo "[$i] 6. Running make -j 2 triple ...."
+  echo "[$i] 6. Running make -j 2 once ...." >> $log_file
+  echo "[$i] 6. Running make -j 2 once ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-1" "make-j2" "make -j 2 -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-j2" "make -j 2 -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-j2" "make -j 2 -C /tmp/linux-2.6.30"
   `date >> $log_file`
   sleep 120
-  echo "[$i] 7. Running make -j 3 triple ...." >> $log_file
-  echo "[$i] 7. Running make -j 3 triple ...."
+  echo "[$i] 7. Running make -j 3 twice ...." >> $log_file
+  echo "[$i] 7. Running make -j 3 twice ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
@@ -87,10 +84,8 @@
   mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-2" "make-j3" "make -j 3 -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-j3" "make -j 3 -C /tmp/linux-2.6.30"
   `date >> $log_file`
   sleep 120
-  echo "[$i] 8. Running make -j 4 triple ...." >> $log_file
-  echo "[$i] 8. Running make -j 4 triple ...."
+  echo "[$i] 8. Running make -j 4 twice ...." >> $log_file
+  echo "[$i] 8. Running make -j 4 twice ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
@@ -98,6 +93,4 @@
   mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-2" "make-j4" "make -j 4 -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-j4" "make -j 4 -C /tmp/linux-2.6.30"
   `date >> $log_file`
 done
Index: /drbl-green-benchmark/diskless-benchmark.sh
===================================================================
--- /drbl-green-benchmark/diskless-benchmark.sh	(revision 98)
+++ /drbl-green-benchmark/diskless-benchmark.sh	(revision 99)
@@ -5,11 +5,13 @@
 log_start=$(date +"%y%m%d-%H%M%S_")
 log_file="/var/log/${log_start}diskless-benchmark.log"
-status_file="/var/log/${log_start}diskless-benchmark-status.log"
+#status_file="/var/log/${log_start}diskless-benchmark-status.log"
+status_file="/dev/null"
 local_zip="/var/log/${log_start}diskless.tar.gz"
 echo "0. Rebooting...." > $log_file
 echo "0. Rebooting...."
-/opt/drbl/sbin/dcs -h "$IP_LIST" remote-linux-txt 2>&1 > $status_file
+/opt/drbl/sbin/dcs -h "$IP_LIST" remote-linux-txt > $status_file 2>&1
 source /home/jazz/.bash_aliases
 up-host-a > /root/.dsh/machines.list
+rm -f /root/.ssh/known_hosts
 
 function mydsh()
@@ -22,5 +24,6 @@
   echo "[$i] 1. Booting...." >> $log_file
   echo "[$i] 1. Booting...."
-  dsh -a -c "reboot" 2>&1 >> $status_file
+  dsh -a -c "rm -f /var/log/*.time.*" >> $status_file 2>&1
+  dsh -a -c "reboot" >> $status_file 2>&1
   `date >> $log_file`
   sleep 120
@@ -41,6 +44,6 @@
   echo "[$i] 4. Running bonnie++ ...."
   `date >> $log_file`
-  # force to run bonnie++ with 512MB RAM (-r), 1024MB (-s)
-  mydsh "$i" "bonnie++" "bonnie++ -u root -d /root -r 512 -s 1024"
+  # force to run bonnie++ with 128MB RAM (-r), 256MB (-s)
+  mydsh "$i" "bonnie++" "bonnie++ -u root -d /root -r 128 -s 256"
   `date >> $log_file`
   sleep 120
@@ -60,26 +63,20 @@
   mydsh "$i" "make-allnoconf" "make -C /tmp/linux-2.6.30 allnoconfig"
   `date >> $log_file`
-  echo "[$i] 5. Running make -j 1 twice ...." >> $log_file
-  echo "[$i] 5. Running make -j 1 twice ...."
+  echo "[$i] 5. Running make -j 1 once ...." >> $log_file
+  echo "[$i] 5. Running make -j 1 once ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-1" "make-j1" "make -j 1 -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-j1" "make -j 1 -C /tmp/linux-2.6.30"
   `date >> $log_file`
   sleep 120
-  echo "[$i] 6. Running make -j 2 triple ...." >> $log_file
-  echo "[$i] 6. Running make -j 2 triple ...."
+  echo "[$i] 6. Running make -j 2 once ...." >> $log_file
+  echo "[$i] 6. Running make -j 2 once ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-1" "make-j2" "make -j 2 -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-2" "make-j2" "make -j 2 -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-j2" "make -j 2 -C /tmp/linux-2.6.30"
   `date >> $log_file`
   sleep 120
-  echo "[$i] 7. Running make -j 3 triple ...." >> $log_file
-  echo "[$i] 7. Running make -j 3 triple ...."
+  echo "[$i] 7. Running make -j 3 twice ...." >> $log_file
+  echo "[$i] 7. Running make -j 3 twice ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
@@ -87,10 +84,8 @@
   mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-2" "make-j3" "make -j 3 -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-j3" "make -j 3 -C /tmp/linux-2.6.30"
   `date >> $log_file`
   sleep 120
-  echo "[$i] 8. Running make -j 4 triple ...." >> $log_file
-  echo "[$i] 8. Running make -j 4 triple ...."
+  echo "[$i] 8. Running make -j 4 twice ...." >> $log_file
+  echo "[$i] 8. Running make -j 4 twice ...."
   `date >> $log_file`
   mydsh "$i-1" "make-clean" "make clean -C /tmp/linux-2.6.30"
@@ -98,6 +93,4 @@
   mydsh "$i-2" "make-clean" "make clean -C /tmp/linux-2.6.30"
   mydsh "$i-2" "make-j4" "make -j 4 -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-clean" "make clean -C /tmp/linux-2.6.30"
-  mydsh "$i-3" "make-j4" "make -j 4 -C /tmp/linux-2.6.30"
   `date >> $log_file`
 done
